==> vala-0.1.1.tar.bz2: vala-0.1.1/vala/valaconstructor.h <==
/* valaconstructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALACONSTRUCTOR_H__
#define __VALACONSTRUCTOR_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_CONSTRUCTOR (vala_constructor_get_type ())
#define VALA_CONSTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructor))
#define VALA_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))
#define VALA_IS_CONSTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONSTRUCTOR))
#define VALA_IS_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONSTRUCTOR))
#define VALA_CONSTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))

typedef struct _ValaConstructorPrivate ValaConstructorPrivate;

/**
 * Represents a class or instance constructor.
 */
struct _ValaConstructor {
	ValaCodeNode parent;
	ValaConstructorPrivate * priv;
};
struct _ValaConstructorClass {
	ValaCodeNodeClass parent;
};

ValaConstructor* vala_constructor_new (ValaSourceReference* source);
ValaStatement* vala_constructor_get_body (ValaConstructor* self);
void vala_constructor_set_body (ValaConstructor* self, ValaStatement* value);
gboolean vala_constructor_get_instance (ValaConstructor* self);
void vala_constructor_set_instance (ValaConstructor* self, gboolean value);
GType vala_constructor_get_type ();

G_END_DECLS

#endif

==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/valaconstructor.h <==
/* valaconstructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALACONSTRUCTOR_H__
#define __VALACONSTRUCTOR_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valasymbol.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_CONSTRUCTOR (vala_constructor_get_type ())
#define VALA_CONSTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructor))
#define VALA_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))
#define VALA_IS_CONSTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONSTRUCTOR))
#define VALA_IS_CONSTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONSTRUCTOR))
#define VALA_CONSTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONSTRUCTOR, ValaConstructorClass))

typedef struct _ValaConstructorPrivate ValaConstructorPrivate;

/**
 * Represents a class or instance constructor.
 */
struct _ValaConstructor {
	ValaSymbol parent;
	ValaConstructorPrivate * priv;
};
struct _ValaConstructorClass {
	ValaSymbolClass parent;
};

ValaConstructor* vala_constructor_new (ValaSourceReference* source);
ValaBlock* vala_constructor_get_body (ValaConstructor* self);
void vala_constructor_set_body (ValaConstructor* self, ValaBlock* value);
ValaFormalParameter* vala_constructor_get_this_parameter (ValaConstructor* self);
void vala_constructor_set_this_parameter (ValaConstructor* self, ValaFormalParameter* value);
gboolean vala_constructor_get_instance (ValaConstructor* self);
void vala_constructor_set_instance (ValaConstructor* self, gboolean value);
GType vala_constructor_get_type (void);

G_END_DECLS

#endif
